@@ -9,4 +9,4 @@ from ._ua import (
     GENERIC_MOBILE,
     GENERIC_WEBKIT,
 )
-from ._util import load_session, save_state, fetch, Session
+from ._util import load_state, save_state, fetch, Session
